Package: shinyMatrix
Title: Shiny Matrix Input Field
Version: 0.8.1
Date: 2026-03-05
Authors@R: person(given = "Andreas",
                  family = "Neudecker",
                  role = c("aut", "cre"),
                  email = "andreas.neudecker@inwt-statistics.de")
Description: Implements a custom matrix input field. 
Depends: R (>= 3.5)
License: MIT + file LICENSE
Encoding: UTF-8
Imports: shiny, jsonlite
Suggests: testthat, covr
RoxygenNote: 7.3.2
URL: https://inwtlab.github.io/shinyMatrix/
NeedsCompilation: no
Packaged: 2026-03-05 15:54:31 UTC; ljabel
Author: Andreas Neudecker [aut, cre]
Maintainer: Andreas Neudecker <andreas.neudecker@inwt-statistics.de>
Repository: CRAN
Date/Publication: 2026-03-05 16:30:10 UTC
Built: R 4.6.0; ; 2026-04-26 12:13:57 UTC; unix
